@@ -1,6 +1,6 @@
 from sls_sdk.lib.imports import internally_imported
 
-with internally_imported("google"):
+with internally_imported():
     from serverless_sdk_schema import TracePayload, RequestResponse
     from google.protobuf import json_format
 
